/*
# ---------------------------------------------------------------------
#
# Copyright (c) CREATIS (Centre de Recherche en Acquisition et Traitement de l'Image
#                        pour la SantÈ)
# Authors : Eduardo Davila, Frederic Cervenansky, Claire Mouton
# Previous Authors : Laurent Guigues, Jean-Pierre Roux
# CreaTools website : www.creatis.insa-lyon.fr/site/fr/creatools_accueil
#
#  This software is governed by the CeCILL-B license under French law and
#  abiding by the rules of distribution of free software. You can  use,
#  modify and/ or redistribute the software under the terms of the CeCILL-B
#  license as circulated by CEA, CNRS and INRIA at the following URL
#  http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
#  or in the file LICENSE.txt.
#
#  As a counterpart to the access to the source code and  rights to copy,
#  modify and redistribute granted by the license, users are provided only
#  with a limited warranty  and the software's author,  the holder of the
#  economic rights,  and the successive licensors  have only  limited
#  liability.
#
#  The fact that you are presently reading this means that you have had
#  knowledge of the CeCILL-B license and that you accept its terms.
# ------------------------------------------------------------------------ */


/*=========================================================================
                                                                                
  Program:   bbtk
  Module:    $RCSfile: bbitkvtkvtkImageData2itkImage.h,v $
  Language:  C++
  Date:      $Date: 2012/11/16 08:50:49 $
  Version:   $Revision: 1.9 $
 
=========================================================================*/
/**
 * \file 
 * \brief class vtkImageData2itkImage : Converts a vtkImageData to a generic itkImage
 */
/**
 * \class vtkImageData2itkImage 
 * \brief Converts a vtkImageData to a generic itkImage
 */
#ifdef _USE_ITK_
#ifdef _USE_VTK_

#ifndef __bbitkvtkvtkImageData2itkImage_h__
#define __bbvitkvtktkImageData2itkImage_h__

#include "bbtkAtomicBlackBox.h"
#include "bbitkImage.h"
#include "vtkImageData.h"
#include "itkProcessObject.h"

namespace bbitkvtk
{

  class /*BBTK_EXPORT*/ vtkImageData2itkImage : public bbtk::AtomicBlackBox  
  {
    
    BBTK_BLACK_BOX_INTERFACE(vtkImageData2itkImage,
			     bbtk::AtomicBlackBox);

    BBTK_DECLARE_INPUT(In,vtkImageData*);
    BBTK_DECLARE_OUTPUT(Out,bbitk::anyImagePointer);
    BBTK_PROCESS(Convert);
    void Convert();

  private:
    // Convert method : template on type of the itk image to be created
    template<class T, unsigned int D> void Convert();
    // stores the pointer on the template itk::VTKImageToImageFilter 
    itk::ProcessObject::Pointer mConverter;
  }; 
  

  //=================================================================
  // AtomicBlackBox description
  BBTK_BEGIN_DESCRIBE_BLACK_BOX(vtkImageData2itkImage,bbtk::AtomicBlackBox);
  BBTK_NAME("vtkImageData2itkImage");
  BBTK_AUTHOR("laurent.guigues@creatis.insa-lyon.fr");
  BBTK_DESCRIPTION("Converts a vtkImageData* to a generic itkImage pointer");
  BBTK_DEFAULT_ADAPTOR();
  BBTK_INPUT(vtkImageData2itkImage,In,
	     "Input vtkImageData",vtkImageData*,"");
  BBTK_OUTPUT(vtkImageData2itkImage,Out,
	      "Output itkImage",
	      bbitk::anyImagePointer,"");
  BBTK_END_DESCRIBE_BLACK_BOX(vtkImageData2itkImage);
  //=================================================================


}
//namespace bbitkvtk
#endif
// _USE_VTK_
#endif
// _USE_ITK_

#endif
